##  Matching Strategy
When the integration maps Collibra assets to fact sheets, there might already be an existing data object fact sheet with the same name. To handle such situations, you can select one of the following options:
  * No Matching: The integration always attempts to create a new fact sheet, regardless of an existing fact sheet. This is the default option.
  * Match By Name: Before creating a new fact sheet, the integration checks for an existing data object fact sheet with the same name. Instead of creating a new fact sheet, the integration updates the existing fact sheet.
